# parts: L-1x2

- L 1x2
- https://robotexiran.com/product/%d8%a8%d8%b3%d8%aa-21-l/

|   |   |
| --- | --- |
| ![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/L-1x2-1.jpg?raw=true) | ![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/L-1x2-2.jpg?raw=true) |
